==> bootstrap-4-5.0.1.jar: META-INF/resources/webjars/tempusdominus-bootstrap-4/src/docs/index.md <==
<main class="bd-masthead" id="content" role="main">
  <div class="container">
    <div class="row align-items-center">
      <div class="col-6 mx-auto col-md-6 order-md-2">
        <img class="img-fluid mb-3 mb-md-0" src="android-chrome-256x256.png" alt="" width="256" height="256">
      </div>
      <div class="col-md-6 order-md-1 text-center text-md-left pr-md-5">
        <h1 class="mb-3">Tempus Dominus</h1>
        <p class="lead">
          Tempus Dominus is the successor to the very popular Eonasdan/bootstrap-datetimepicker. 
		  The plugin provide a robust date and time picker designed to integrate into your Bootstrap project.
        </p>
        <div class="d-flex flex-column flex-md-row lead mb-3">
          <a href="Usage/" class="btn btn-lg mb-3 mb-md-0 mr-md-3" id="getstarted">Get started</a>
          <a href="Installing/" class="btn btn-lg btn-outline-secondary">Download</a>
        </div>
        <p class="text-muted mb-0">
         Currently v5.0.1
        </p>
      </div>
    </div>
  </div>
</main>
<div class="masthead-followup row m-0 border border-white">
	<div class="col-12 col-md-6 p-3 p-md-5 bg-light border border-white">
		<span class="fa fa-download"></span>
		<h3>Installation</h3>
		<p>Include Tempus Dominus's source Sass and JavaScript files via npm</p>
		<pre>
<code>
npm i tempusdominus-bootstrap-4
</code>
		</pre>
		<hr class="half-rule"/>
		<a class="btn btn-outline-primary" href="Installing/">Read installation docs</a>
	</div>
	<div class="col-12 col-md-6 p-3 p-md-5 bg-light border border-white">
		<span class="fa fa-cloud-download"></span>
		<h3>CDNJS</h3>
		<p>When you only need to include Tempus Dominus's compiled CSS or JS, you can use CDNJS.</p>
		<pre>
<code>
&lt;script type=&quot;text/javascript&quot; src=&quot;https://cdnjs.cloudflare.com/ajax/libs/jquery/3.3.1/jquery.min.js&quot;&gt;&lt;/script&gt;
&lt;script type=&quot;text/javascript&quot; src=&quot;https://cdnjs.cloudflare.com/ajax/libs/moment.js/2.22.2/moment.min.js&quot;&gt;&lt;/script&gt;
&lt;script type=&quot;text/javascript&quot; src=&quot;https://cdnjs.cloudflare.com/ajax/libs/tempusdominus-bootstrap-4/5.0.1/js/tempusdominus-bootstrap-4.min.js&quot;&gt;&lt;/script&gt;
&lt;link rel=&quot;stylesheet&quot; href=&quot;https://cdnjs.cloudflare.com/ajax/libs/tempusdominus-bootstrap-4/5.0.1/css/tempusdominus-bootstrap-4.min.css&quot; /&gt;
</code>
		</pre>
		<hr class="half-rule"/>
		<a class="btn btn-outline-primary" href="/Functions">Explore the docs</a>
	 </div>
</div>

==> bootstrap-4-5.1.1.jar: META-INF/resources/webjars/tempusdominus-bootstrap-4/src/docs/index.md <==
<main class="bd-masthead" id="content" role="main">
  <div class="container">
    <div class="row align-items-center">
      <div class="col-6 mx-auto col-md-6 order-md-2">
        <img class="img-fluid mb-3 mb-md-0" src="android-chrome-256x256.png" alt="" width="256" height="256">
      </div>
      <div class="col-md-6 order-md-1 text-center text-md-left pr-md-5">
        <h1 class="mb-3">Tempus Dominus</h1>
        <p class="lead">
          Tempus Dominus is the successor to the very popular Eonasdan/bootstrap-datetimepicker. 
		  The plugin provide a robust date and time picker designed to integrate into your Bootstrap project.
        </p>
        <div class="d-flex flex-column flex-md-row lead mb-3">
          <a href="Usage/" class="btn btn-lg mb-3 mb-md-0 mr-md-3" id="getstarted">Get started</a>
          <a href="Installing/" class="btn btn-lg btn-outline-secondary">Download</a>
        </div>
        <p class="text-muted mb-0">
         Currently v5.0.1
		 <script async type="text/javascript" src="//cdn.carbonads.com/carbon.js?serve=CK7DC5QN&placement=eonasdangithubio" id="_carbonads_js"></script>
        </p>
      </div>
    </div>
  </div>
</main>
<div class="masthead-followup row m-0 border border-white">
	<div class="col-12 col-md-6 p-3 p-md-5 bg-light border border-white">
		<span class="fa fa-download"></span>
		<h3>Installation</h3>
		<p>Include Tempus Dominus's source Sass and JavaScript files via npm</p>
		<pre>
<code>
npm i tempusdominus-bootstrap-4
</code>
		</pre>
		<hr class="half-rule"/>
		<a class="btn btn-outline-primary" href="Installing/">Read installation docs</a>
	</div>
	<div class="col-12 col-md-6 p-3 p-md-5 bg-light border border-white">
		<span class="fa fa-cloud-download"></span>
		<h3>CDNJS</h3>
		<p>When you only need to include Tempus Dominus's compiled CSS or JS, you can use CDNJS.</p>
		<pre>
<code>
&lt;script type=&quot;text/javascript&quot; src=&quot;https://cdnjs.cloudflare.com/ajax/libs/jquery/3.3.1/jquery.min.js&quot;&gt;&lt;/script&gt;
&lt;script type=&quot;text/javascript&quot; src=&quot;https://cdnjs.cloudflare.com/ajax/libs/moment.js/2.22.2/moment.min.js&quot;&gt;&lt;/script&gt;
&lt;script type=&quot;text/javascript&quot; src=&quot;https://cdnjs.cloudflare.com/ajax/libs/tempusdominus-bootstrap-4/5.0.1/js/tempusdominus-bootstrap-4.min.js&quot;&gt;&lt;/script&gt;
&lt;link rel=&quot;stylesheet&quot; href=&quot;https://cdnjs.cloudflare.com/ajax/libs/tempusdominus-bootstrap-4/5.0.1/css/tempusdominus-bootstrap-4.min.css&quot; /&gt;
</code>
		</pre>
		<hr class="half-rule"/>
		<a class="btn btn-outline-primary" href="/Functions">Explore the docs</a>
	 </div>
</div>
